@@ -18,7 +18,7 @@ Then, on Travis, for the build where you build your docs, add
 to the end of the build to deploy the docs to GitHub pages.  This will only
 run on the master branch, and won't run on pull requests.
 
-For more information, see https://gforsyth.github.io/doctr/docs/
+For more information, see https://drdoctr.github.io/doctr/docs/
 """
 
 import sys
@@ -28,8 +28,8 @@ import argparse
 from textwrap import dedent
 
 from .local import (generate_GitHub_token, encrypt_variable, encrypt_file,
-    upload_GitHub_deploy_key, generate_ssh_key)
-from .travis import setup_GitHub_push, commit_docs, push_docs, get_repo
+    upload_GitHub_deploy_key, generate_ssh_key, check_repo_exists)
+from .travis import setup_GitHub_push, commit_docs, push_docs, get_current_repo
 from . import __version__
 
 def get_parser():
@@ -54,14 +54,18 @@ options available.
         used 'doctr configure --token'.""")
     deploy_parser.add_argument('--key-path', default='github_deploy_key.enc',
         help="""Path of the encrypted GitHub deploy key. The default is %(default)r.""")
-    deploy_parser.add_argument('--built-docs', default='docs/_build/html',
+    deploy_parser.add_argument('--built-docs', default=None,
         help="""Location of the built html documentation to be deployed to
-        gh-pages. The default is %(default)r.""")
+        gh-pages. If not specified, Doctr will try to automatically detect build location""")
     deploy_parser.add_argument('--gh-pages-docs', default='docs',
         help="""Directory to deploy the html documentation to on gh-pages. The
         default is %(default)r.""")
     deploy_parser.add_argument('--tmp-dir', default='_docs',
         help="""Temporary directory used on gh-pages. The default is %(default)r.""")
+    deploy_parser.add_argument('--deploy-repo', default=None, help="""Repo to
+        deploy the docs to. By default, it deploys to the repo Doctr is run from.""")
+    deploy_parser.add_argument('--no-require-master', dest='require_master', action='store_false',
+        default=True, help="""Allow docs to be pushed from a branch other than master""")
 
 
     configure_parser = subcommand.add_parser('configure', help="Configure doctr. This command should be run locally (not on Travis).")
@@ -74,8 +78,8 @@ options available.
         public repositories for the user. This option is not recommended
         unless you are using a separate GitHub user for deploying.""")
     configure_parser.add_argument("--no-upload-key", action="store_false", default=True,
-        dest="upload_key", help="""Don't automatically upload the deploy key
-        to GitHub.""")
+        dest="upload_key", help="""Don't automatically upload the deploy key to GitHub. If you select this
+        option, you will not be prompted for your GitHub credentials. """)
     configure_parser.add_argument('--key-path', default='github_deploy_key',
         help="""Path to save the encrypted GitHub deploy key. The default is %(default)r.
     The .enc extension is added to the file automatically.""")
@@ -89,7 +93,10 @@ def process_args(parser):
         parser.print_usage()
         parser.exit(1)
 
-    return args.func(args, parser)
+    try:
+        return args.func(args, parser)
+    except RuntimeError as e:
+        sys.exit("Error: " + e.args[0])
 
 def on_travis():
     return os.environ.get("TRAVIS_JOB_NUMBER", '')
@@ -99,9 +106,12 @@ def deploy(args, parser):
         parser.error("doctr does not appear to be running on Travis. Use "
             "doctr deploy --force to run anyway.")
 
-    repo = get_repo()
-    if setup_GitHub_push(repo, auth_type='token' if args.token else
-        'deploy_key', full_key_path=args.key_path):
+    build_repo = get_current_repo()
+    deploy_repo = args.deploy_repo or build_repo
+
+    if setup_GitHub_push(deploy_repo, auth_type='token' if args.token else
+                         'deploy_key', full_key_path=args.key_path,
+                         require_master=args.require_master):
         commit_docs(built_docs=args.built_docs,
             gh_pages_docs=args.gh_pages_docs, tmp_dir=args.tmp_dir)
         push_docs()
@@ -122,41 +132,52 @@ def configure(args, parser):
         parser.error("doctr appears to be running on Travis. Use "
             "doctr configure --force to run anyway.")
 
-    repo = input("What repo do you want to build the docs for (org/reponame, like 'gforsyth/doctr')? ")
+    build_repo = input("What repo do you want to build the docs for (org/reponame, like 'drdoctr/doctr')? ")
+    check_repo_exists(build_repo)
+
+    deploy_repo = input("What repo do you want to deploy the docs to? [{build_repo}] ".format(build_repo=build_repo))
+    if not deploy_repo:
+        deploy_repo = build_repo
+
+    if deploy_repo != build_repo:
+        check_repo_exists(deploy_repo)
 
     N = IncrementingInt(1)
 
+    header = "\n================== You should now do the following ==================\n"
+
     if args.token:
         token = generate_GitHub_token()
         encrypted_variable = encrypt_variable("GH_TOKEN={token}".format(token=token).encode('utf-8'),
-        repo=repo)
+            build_repo=build_repo)
         print(dedent("""
         A personal access token for doctr has been created.
 
         You can go to https://github.com/settings/tokens to revoke it."""))
 
-        print("\n============ You should now do the following ============\n")
+        print(header)
     else:
-        ssh_key = generate_ssh_key("doctr deploy key for {repo}".format(repo=repo), keypath=args.key_path)
+        ssh_key = generate_ssh_key("doctr deploy key for {deploy_repo}".format(deploy_repo=deploy_repo), keypath=args.key_path)
         key = encrypt_file(args.key_path, delete=True)
-        encrypted_variable = encrypt_variable(b"DOCTR_DEPLOY_ENCRYPTION_KEY=" + key, repo=repo)
+        encrypted_variable = encrypt_variable(b"DOCTR_DEPLOY_ENCRYPTION_KEY=" + key, build_repo=build_repo)
 
-        deploy_keys_url = 'https://github.com/{repo}/settings/keys'.format(repo=repo)
+        deploy_keys_url = 'https://github.com/{deploy_repo}/settings/keys'.format(deploy_repo=deploy_repo)
 
         if args.upload_key:
 
-            upload_GitHub_deploy_key(repo, ssh_key)
+            upload_GitHub_deploy_key(deploy_repo, ssh_key)
 
             print(dedent("""
-            The deploy key has been added for {repo}.
+            The deploy key has been added for {deploy_repo}.
 
             You can go to {deploy_keys_url} to revoke the deploy key.\
-            """.format(repo=repo, deploy_keys_url=deploy_keys_url, keypath=args.key_path)))
-            print("\n============ You should now do the following ============\n")
+            """.format(deploy_repo=deploy_repo, deploy_keys_url=deploy_keys_url, keypath=args.key_path)))
+            print(header)
         else:
-            print("\n============ You should now do the following ============\n")
+            print(header)
             print(dedent("""\
-            {N}. Go to {deploy_keys_url} and add the following as a new key:
+            {N}. Go to {deploy_keys_url}
+            and add the following as a new key:
 
             {ssh_key}
             Be sure to allow write access for the key.
@@ -165,15 +186,16 @@ def configure(args, parser):
         # TODO: Should we just delete the public key?
 
         print(dedent("""\
-        {N}. Commit the file {keypath}.enc. The file {keypath}.pub contains the
-        public deploy key for GitHub. It does not need to be
-        committed.
+        {N}. Commit the file {keypath}.enc.
+        The file {keypath}.pub contains the public deploy key for GitHub. It
+        does not need to be committed.
         """.format(keypath=args.key_path, N=N)))
 
+    options = ''
     if args.key_path != 'github_deploy_key':
-        options = '--key-path {keypath}.enc'.format(keypath=args.key_path)
-    else:
-        options = ''
+        options += ' --key-path {keypath}.enc'.format(keypath=args.key_path)
+    if deploy_repo != build_repo:
+        options += ' --deploy-repo {deploy_repo}'.format(deploy_repo=deploy_repo)
 
     print(dedent("""\
     {N}. Add
