@@ -7,6 +7,7 @@ import shlex
 import shutil
 import subprocess
 import sys
+import glob
 
 from cryptography.fernet import Fernet
 
@@ -118,7 +119,7 @@ def run(args):
     if returncode != 0:
         sys.exit(returncode)
 
-def get_repo():
+def get_current_repo():
     """
     Get the GitHub repo name for the current directory.
 
@@ -131,7 +132,7 @@ def get_repo():
     _, org, git_repo = remote_url.rsplit('.git', 1)[0].rsplit('/', 2)
     return (org + '/' + git_repo)
 
-def setup_GitHub_push(repo, auth_type='deploy_key', full_key_path='github_deploy_key.enc'):
+def setup_GitHub_push(deploy_repo, auth_type='deploy_key', full_key_path='github_deploy_key.enc', require_master=True):
     """
     Setup the remote to push to GitHub (to be run on Travis).
 
@@ -149,8 +150,9 @@ def setup_GitHub_push(repo, auth_type='deploy_key', full_key_path='github_deploy
     TRAVIS_BRANCH = os.environ.get("TRAVIS_BRANCH", "")
     TRAVIS_PULL_REQUEST = os.environ.get("TRAVIS_PULL_REQUEST", "")
 
-    if TRAVIS_BRANCH != "master":
-        print("The docs are only pushed to gh-pages from master", file=sys.stderr)
+    if TRAVIS_BRANCH != "master" and require_master:
+        print("The docs are only pushed to gh-pages from master. To allow pushing from "
+        "a non-master branch, use the --no-require-master flag", file=sys.stderr)
         print("This is the {TRAVIS_BRANCH} branch".format(TRAVIS_BRANCH=TRAVIS_BRANCH), file=sys.stderr)
         return False
 
@@ -166,14 +168,14 @@ def setup_GitHub_push(repo, auth_type='deploy_key', full_key_path='github_deploy
     if auth_type == 'token':
         token = get_token()
         run(['git', 'remote', 'add', 'doctr_remote',
-            'https://{token}@github.com/{repo}.git'.format(token=token.decode('utf-8'),
-                repo=repo)])
+            'https://{token}@github.com/{deploy_repo}.git'.format(token=token.decode('utf-8'),
+                deploy_repo=deploy_repo)])
     else:
         keypath, key_ext = full_key_path.rsplit('.', 1)
         key_ext = '.' + key_ext
         setup_deploy_key(keypath=keypath, key_ext=key_ext)
         run(['git', 'remote', 'add', 'doctr_remote',
-            'git@github.com:{repo}.git'.format(repo=repo)])
+            'git@github.com:{deploy_repo}.git'.format(deploy_repo=deploy_repo)])
 
     print("Fetching doctr remote")
     run(['git', 'fetch', 'doctr_remote'])
@@ -217,7 +219,7 @@ def create_gh_pages():
         print("Adding .nojekyll file to gh-pages branch")
         run(['touch', '.nojekyll'])
         run(['git', 'add', '.nojekyll'])
-        run(['git', 'commit', '-m', '"create new gh-pages branch with .nojekyll"'])
+        run(['git', 'commit', '-m', 'Create new gh-pages branch with .nojekyll'])
         print("Pushing gh-pages branch to remote")
         run(['git', 'push', '-u', 'doctr_remote', 'gh-pages'])
         #return to master branch
@@ -226,13 +228,79 @@ def create_gh_pages():
         return True
     return False
 
+def find_sphinx_build_dir():
+    """
+    Find build subfolder within sphinx docs directory.
+
+    This is called by :func:`commit_docs` if keyword arg ``built_docs`` is not
+    specified on the command line.
+    """
+    build = glob.glob('**/*build/html', recursive=True)
+    if not build:
+        raise RuntimeError("Could not find Sphinx build directory automatically")
+    build_folder = build[0]
+
+    return build_folder
+
 # Here is the logic to get the Travis job number, to only run commit_docs in
 # the right build.
 #
 # TRAVIS_JOB_NUMBER = os.environ.get("TRAVIS_JOB_NUMBER", '')
 # ACTUAL_TRAVIS_JOB_NUMBER = TRAVIS_JOB_NUMBER.split('.')[1]
 
-def commit_docs(*, built_docs='docs/_build/html', gh_pages_docs='docs', tmp_dir='_docs'):
+def sync_from_log(src, dst, log_file):
+    """
+    Sync the files in ``src`` to ``dst``.
+
+    The files that are synced are logged to ``log_file``. If ``log_file``
+    exists, the files in ``log_file`` are removed first.
+
+    Returns ``(added, removed)``, where added is a list of all files synced from
+    ``src`` (even if it already existed in ``dst``), and ``removed`` is every
+    file from ``log_file`` that was removed from ``dst`` because it wasn't in
+    ``src``.
+    """
+    from os.path import join, exists, isdir
+    if not src.endswith(os.sep):
+        src += os.sep
+
+    added, removed = [], []
+
+    if not exists(log_file):
+        # Assume this is the first run
+        print("%s doesn't exist. Not removing any files." % log_file)
+    else:
+        with open(log_file) as f:
+            files = f.read().strip().split('\n')
+
+        for new_f in files:
+            new_f = new_f.strip()
+            if exists(new_f):
+                os.remove(new_f)
+                removed.append(new_f)
+            else:
+                print("Warning: File %s doesn't exist." % new_f, file=sys.stderr)
+
+    files = glob.iglob(join(src, '**'), recursive=True)
+    # sorted makes this easier to test
+    for f in sorted(files):
+        if f == src:
+            continue
+        new_f = join(dst, f[len(src):])
+        if isdir(f):
+            os.makedirs(new_f, exist_ok=True)
+        else:
+            shutil.copy2(f, new_f)
+            added.append(new_f)
+            if new_f in removed:
+                removed.remove(new_f)
+
+    with open(log_file, 'w') as f:
+        f.write('\n'.join(added))
+
+    return added, removed
+
+def commit_docs(*, built_docs=None, gh_pages_docs='docs', tmp_dir='_docs', log_file='.doctr-files'):
     """
     Commit the docs to ``gh-pages``
 
@@ -240,15 +308,23 @@ def commit_docs(*, built_docs='docs/_build/html', gh_pages_docs='docs', tmp_dir=
     remote, has been run and returned True.
 
     """
-    if gh_pages_docs == '.':
-        raise NotImplementedError("Base directory docs deploying is not yet implemented.")
+    if not built_docs:
+        built_docs = find_sphinx_build_dir()
     print("Moving built docs into place")
-    shutil.copytree(built_docs, tmp_dir)
-    if os.path.exists(gh_pages_docs):
-        # Won't exist on the first build
-        shutil.rmtree(gh_pages_docs)
-    os.rename(tmp_dir, gh_pages_docs)
-    run(['git', 'add', '-A', gh_pages_docs])
+    if gh_pages_docs == '.':
+        added, removed = sync_from_log(src=built_docs, dst=gh_pages_docs,
+            log_file=log_file)
+        for f in added:
+            run(['git', 'add', f])
+        for f in removed:
+            run(['git', 'rm', f])
+    else:
+        shutil.copytree(built_docs, tmp_dir)
+        if os.path.exists(gh_pages_docs):
+            # Won't exist on the first build
+            shutil.rmtree(gh_pages_docs)
+        os.rename(tmp_dir, gh_pages_docs)
+        run(['git', 'add', '-A', gh_pages_docs])
 
 def push_docs():
     """
